summaryrefslogtreecommitdiff
path: root/src/osd/OSD.h
diff options
context:
space:
mode:
authorSamuel Just <sam.just@inktank.com>2013-05-13 09:50:14 -0700
committerSamuel Just <sam.just@inktank.com>2013-05-13 09:52:23 -0700
commit9bb58b2ac9e4f72d91eb2008cd706cbb4eca7819 (patch)
tree8da2f9b2b6e3605a098a9fe1ec6064b35f7c0ffe /src/osd/OSD.h
parentc24ffc16dd335ca63e1439261f6d3c3e08e7a1dd (diff)
downloadceph-9bb58b2ac9e4f72d91eb2008cd706cbb4eca7819.tar.gz
OSD: We need to wait on CLEARING_DIR, not DELETED_DIR
Signed-off-by: Samuel Just <sam.just@inktank.com> Reviewed-by: Sage Weil <sage@inktank.com>
Diffstat (limited to 'src/osd/OSD.h')
-rw-r--r--src/osd/OSD.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/osd/OSD.h b/src/osd/OSD.h
index 905af9cfb2a..b14592880aa 100644
--- a/src/osd/OSD.h
+++ b/src/osd/OSD.h
@@ -208,15 +208,15 @@ public:
Mutex::Locker l(lock);
stop_deleting = true;
/**
* If we are in DELETING_DIR or DELETED_DIR, there are in progress
* operations we have to wait for before continuing on. States
* DELETED_DIR, QUEUED, and CANCELED either check for stop_deleting
* prior to performing any operations or signify the end of the
* deleting process. We don't want to wait to leave the QUEUED
- * state, because this might block the caller behind entire pg
- * removals.
+ * state, because this might block the caller behind an entire pg
+ * removal.
*/
- while (status == DELETING_DIR || status == DELETED_DIR)
+ while (status == DELETING_DIR || status == CLEARING_DIR)
cond.Wait(lock);
return status != DELETED_DIR;
} ///< @return true if we don't need to recreate the collection
@@ -208,15 +208,15 @@ public:
stop_deleting = true;
/**
- * If we are in DELETING_DIR or DELETED_DIR, there are in progress
+ * If we are in DELETING_DIR or CLEARING_DIR, there are in progress
* operations we have to wait for before continuing on. States
* DELETED_DIR, QUEUED, and CANCELED either check for stop_deleting